@@ -5,7 +5,7 @@ use URI;
 use JSON;
 use Encode;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =encoding utf-8
 
@@ -44,7 +44,7 @@ or
 
   $AutoSuggest->json(1);
 
-Explicitally enable the return the decoded L<JSON> object when calling C<search("term")>
+Explicitally enable the return of the decoded L<JSON> object when calling C<search("term")>
 
 =item strip_html
 
